
//Data Collection Variables
Table myTable;
float [][] dataMatrix = null;

int numRows, numColumns;

ArrayList<String> birdSpecies = new ArrayList<String>();
ArrayList<String> states      = new ArrayList<String>();

//Unfolding Map Variables
UnfoldingMap map;
List stateMarkers   = new ArrayList();
Location usa_center = new Location(52.5827, -120.1207);
List<Marker> markersList = new ArrayList<Marker>();

//Map State Centers
HashMap<String, Location> stateCenters = new HashMap<String, Location>();

void setup()
{
  size(1250, 1000, P2D);
  noSmooth();
  frameRate(60);
   
  if(frame != null)
    frame.setResizable(true);
  
  //Store CSV File
  myTable = loadTable("birdData.csv", "header");
  dataMatrix = new float[myTable.getRowCount()][myTable.getColumnCount() - 2];

  for(int i = 0; i < myTable.getRowCount(); i++)
  {
    //Add to lists
    states.add(capitalizeFirstLetter(myTable.getString(i, 0)));
    birdSpecies.add(myTable.getString(i, 1));
    
    //Add to Data Matrix
    for(int j = 2; j < myTable.getColumnCount() - 2; j++)
    {
      dataMatrix[i][j - 2] = myTable.getFloat(i, j - 2) * 100.0;
    }
  }
 
  println(myTable.getRowCount());
  println(myTable.getColumnCount());
  
  //Set up Map
  //Json Data Obtained From:
  //    http://eric.clst.org/wupl/Stuff/gz_2010_us_040_00_500k.json
  map = new UnfoldingMap(this);
  map.zoomAndPanTo(usa_center, 4);
  map.setPanningRestriction(usa_center, 0);
  map.setZoomRange(4, 4);
  MapUtils.createDefaultEventDispatcher(this, map);
  List states = GeoJSONReader.loadData(this, "us_states.geo.json");
  markersList = MapUtils.createSimpleMarkers(states);

  List stateMarkers = MapUtils.createSimpleMarkers(states);
  map.addMarkers(stateMarkers);

  fillHashTable();
}



//http://stackoverflow.com/questions/1149855/how-to-upper-case-every-first-letter-of-word-in-a-string
String capitalizeFirstLetter(String s)
{
  StringBuffer res = new StringBuffer();

  String[] strArr = s.split(" ");
  for (String str : strArr) 
  {
    char[] stringArray = str.trim().toCharArray();
    stringArray[0] = Character.toUpperCase(stringArray[0]);
    str = new String(stringArray);

    res.append(str).append(" ");
  }

 // System.out.print("Result: " + res.toString().trim());
  //print(":" + res.toString().trim() + ":");
  return res.toString().trim();
}
    
    
void fillHashTable()
{
  stateCenters.put("Maine", new Location(45.5000, -69.0000));
  stateCenters.put("Massachusetts", new Location(42.3000, -71.8000));
  stateCenters.put("Michigan", new Location(43.6867, -85.0102));
  stateCenters.put("Montana", new Location(47.035, -109.649));
  stateCenters.put("Nevada", new Location(39.358, -116.660));
  stateCenters.put("New Jersey", new Location(40.191, -74.673));
  stateCenters.put("New York", new Location(42.8494, -75.1890));
  stateCenters.put("North Carolina", new Location(35.5, -79.0));
  stateCenters.put("Ohio", new Location(40.3000, -82.5000));
  stateCenters.put("Pennsylvania", new Location(40.873, -77.798));
  stateCenters.put("Rhode Island", new Location(41.7000, -71.5000));
  stateCenters.put("Tennessee", new Location(35.847, -86.354));
  stateCenters.put("Texas", new Location(31.5000, -98.5000));
  stateCenters.put("Utah", new Location(39.323, -111.675));
  stateCenters.put("Washington", new Location(47.5000, -120.5000));
  stateCenters.put("Wisconsin", new Location(44.5000, -89.5000));
  stateCenters.put("Maryland", new Location(39.0000, -76.5000));
  stateCenters.put("Alabama", new Location(32.7000, -86.7000));
  stateCenters.put("Alaska", new Location(65.5000, -151.5000));
  stateCenters.put("Arizona", new Location(34.294, -111.667));
  stateCenters.put("Arkansas", new Location(34.898, -92.433));
  stateCenters.put("California", new Location(37.0000, -120.0000));
  stateCenters.put("Colorado", new Location(38.999, -105.548));
  stateCenters.put("Conneticut", new Location(41.6000, -72.7000));
  stateCenters.put("Delaware", new Location(39.0000, -75.5000));
  stateCenters.put("Florida", new Location(28.1000, -81.6000));
  stateCenters.put("Georgia", new Location(32.651, -83.452));
  stateCenters.put("Hawaii", new Location(21.3114, -157.7964));
  stateCenters.put("Idaho", new Location(43.786, -114.651));
  stateCenters.put("Illinois", new Location(40.064, -89.197));
  stateCenters.put("Indiana", new Location(39.910, -86.278));
  stateCenters.put("Iowa", new Location(42.073, -93.497));
  stateCenters.put("Kansas", new Location(38.485, -98.382));
  stateCenters.put("Kentucky", new Location(37.434, -85.405));
  stateCenters.put("Louisiana", new Location(31.0413, -92.3360));
  stateCenters.put("Minnesota", new Location(46.324, -94.325));
  stateCenters.put("Mississippi", new Location(32.7000, -89.5000));
  stateCenters.put("Missouri", new Location(38.368, -92.478));
  stateCenters.put("Nebraska", new Location(41.525, -99.807)); 
  stateCenters.put("New Hampshire", new Location(43.7000, -71.5000));
  stateCenters.put("New Mexico", new Location(34.521, -106.108));
  stateCenters.put("North Dakota", new Location(47.447, -100.471));
  stateCenters.put("Oklahoma", new Location(35.582, -97.505));
  stateCenters.put("Oregon", new Location(43.935, -120.552));
  stateCenters.put("South Carolina", new Location(33.903, -80.886));
  stateCenters.put("South Dakota", new Location(44.436, -100.229));
  stateCenters.put("Vermont", new Location(44.066, -72.648));
  stateCenters.put("Virginia", new Location(37.5000, -79.0000));
  stateCenters.put("West Virginia", new Location(38.539, -80.744));
  stateCenters.put("Wyoming", new Location(43.002, -107.557));
}

































//OLD CODE

  
 /* println("LISTING STATES:");
  for(int i = 0; i < markersList.size(); i++)
  {
    print(i + " ");
    //println(stateList.get(i).getStringProperty("NAME"));
    //println(stateList.get(i).getProperties());
    println("HHHHHHHHH");
    print(markersList.get(i).getStringProperty("NAME"));
    println(markersList.get(i).getLocation());
    //println(markersList.get(i).getProperties());
    
    Location manyloc = markersList.get(i).getLocation();
    float xy[] = map.getScreenPositionFromLocation(manyloc);
    println(xy);
    //println(states.get(i).getClass().getName());
    //println(states.get(i));
    //println(states.getId(i));
    //Feature a = states.get(i);
    //println(a);
  }*/
  
  
    //stateList = GeoJSONReader.loadData(this, "us_states.geo.json");

  
    /*for(int i = 0; i < markersList.size(); i++)
  {
    print(i + " ");
    print(markersList.get(i).getStringProperty("NAME"));
    println(markersList.get(i).getLocation());
    
    Location manyloc = markersList.get(i).getLocation();
    float xy[] = map.getScreenPositionFromLocation(manyloc);
    println(xy);

    ellipse(xy[0], xy[1], 5, 5);
  }*/
